<?php

/* ---------------------------------------------------------------------- */
/*	Widget Areas
/* ---------------------------------------------------------------------- */

function gb_framework_widgets_init() {

	// Blog Widget Area
	register_sidebar(array(
		'name'          => __('Blog Widget Area', 'gb_framework'),
		'id'            => 'blog-widget-area',
		'description'   => __('Only for blog pages and posts.', 'gb_framework'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget-title">',
		'after_title'   => '</h6>',
	));
	
	// Shop Widget Area
	register_sidebar(array(
		'name'          => __('Shop Widget Area', 'gb_framework'),
		'id'            => 'shop-widget-area',
		'description'   => __('Only for shop.', 'gb_framework'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget-title">',
		'after_title'   => '</h6>',
	));

	// General Widget Area
	register_sidebar(array(
		'name'          => __('Sidebar Widget Area', 'gb_framework'),
		'id'            => 'sidebar-widget-area',
		'description'   => __('For all pages and with sidebar.', 'gb_framework'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget-title">',
		'after_title'   => '</h6>',
	));

	// Left 1 Footer Widget Area
	register_sidebar(array(
		'name'          => __('Left 1 Footer Widget Area', 'gb_framework'),
		'id'            => 'left1-footer-widget-area',
		'description'   => __('Left 1 side of footer.', 'gb_framework'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5> ',
		'after_title'   => '</h5>',
	));
	// Left 2 Footer Widget Area
	register_sidebar(array(
		'name'          => __('Left 2 Footer Widget Area', 'gb_framework'),
		'id'            => 'left2-footer-widget-area',
		'description'   => __('Left 2 side of footer', 'gb_framework'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5> ',
		'after_title'   => '</h5>',
	));
	
	// Right 1 Footer Widget Area
	register_sidebar(array(
		'name'          => __('Right 1 Footer Widget Area', 'gb_framework'),
		'id'            => 'right1-footer-widget-area',
		'description'   => __('Right 1 side of footer', 'gb_framework'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5> ',
		'after_title'   => '</h5>',
	));
	// Right 2 Footer Widget Area
	register_sidebar(array(
		'name'          => __('Right 2 Footer Widget Area', 'gb_framework'),
		'id'            => 'right2-footer-widget-area',
		'description'   => __('Right 2 side of footer', 'gb_framework'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5> ',
		'after_title'   => '</h5>',
	));

}
add_action('widgets_init', 'gb_framework_widgets_init');

/* ---------------------------------------------------------------------- */
/*	Custom Widgets
/* ---------------------------------------------------------------------- */

/* ---------------------------------------------------- */
/*	Latest Project
/* ---------------------------------------------------- */

class gb_Project_Widget extends WP_Widget {

	function gb_Project_Widget() {
		$widget_ops = array( 'classname' => 'gb-project-feed', 'description' => __('Display the most recent projects.', 'gb_framework') );
		$this->WP_Widget( 'gb-project-feed', __('Jedkey Recent Projects', 'gb_framework'), $widget_ops );
	}

	function form( $instance ) {

		$instance = wp_parse_args( (array) $instance, array('title'          => __('Recent Projects', 'gb_framework'),
															'project_count'    => '3'
															) );

		$title = esc_attr( $instance['title'] );
		$project_count = absint( $instance['project_count'] );

		?>

		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'gb_framework'); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $title; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('project_count'); ?>"><?php _e('Projects count:', 'gb_framework'); ?></label>
			<input size="2" type="text" id="<?php echo $this->get_field_id('project_count'); ?>" name="<?php echo $this->get_field_name('project_count'); ?>" value="<?php echo $project_count; ?>" />
		</p>


		<?php

	}

	function update( $new_instance, $old_instance ) {

		$instance = $old_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['project_count'] = strip_tags( $new_instance['project_count'] );
		$instance['widget_id'] = strip_tags( uniqid( $instance['project_count'] ) );

		// Refresh Cache
		delete_transient( 'gb_framework_projects_feed-' . $instance['widget_id'] );

		return $instance;
	}

	function widget( $args, $instance ) {

		extract( $args );

		$title = esc_attr( $instance['title'] );
		$project_count = absint( $instance['project_count'] );
		$widget_id = esc_attr( $instance['widget_id'] );

		echo $before_widget;

		if( $title )
			echo $before_title . $title . $after_title;

		// Display tweets
		echo gb_framework_projects_feed( $project_count, $widget_id );

		echo $after_widget;
	}

}

add_action( 'widgets_init', create_function('', "register_widget('gb_Project_Widget');") );




/* ---------------------------------------------------- */
/*	Flickr Feed
/* ---------------------------------------------------- */

class gb_Flickr_Feed_Widget extends WP_Widget {

	function gb_Flickr_Feed_Widget() {
		$widget_ops = array( 'classname' => 'gb-flickr-feed', 'description' => __('Display the most recent flickr images.', 'gb_framework') );
		$this->WP_Widget( 'gb-flickr-feed', __('Jedkey Flickr Feed', 'gb_framework'), $widget_ops );
	}

	function form( $instance ) {

		$instance = wp_parse_args( (array) $instance, array('title'       => __('Flickr Feed', 'gb_framework'),
															'flickr_id'   => '',
															'image_count' => '12'
															) );

		$title = esc_attr( $instance['title'] );
		$flickr_id = esc_attr( $instance['flickr_id'] );
		$image_count = absint( $instance['image_count'] );

		?>

		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _x('Title:', 'gb_framework'); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $title; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('flickr_id'); ?>"><?php _x('Flickr ID:', 'gb_framework'); ?></label>
			<input class="widefat" type="text" id="<?php echo $this->get_field_id('flickr_id'); ?>" name="<?php echo $this->get_field_name('flickr_id'); ?>" value="<?php echo $flickr_id; ?>" />
			<small>Get your Flickr ID at <a href="http://idgettr.com/" title="idGettr &mdash; Find your Flickr ID" target="_blank">http://idgettr.com/</a></small>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('image_count'); ?>"><?php _x('Image count:', 'gb_framework'); ?></label>
			<input size="2" type="text" id="<?php echo $this->get_field_id('image_count'); ?>" name="<?php echo $this->get_field_name('image_count'); ?>" value="<?php echo $image_count; ?>" />
		</p>

		<?php

	}

	function update( $new_instance, $old_instance ) {

		$instance = $old_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['flickr_id'] = strip_tags( $new_instance['flickr_id'] );
		$instance['image_count'] = strip_tags( $new_instance['image_count'] );
		$instance['widget_id'] = strip_tags( uniqid( $instance['flickr_id'] ) );

		// Refresh Cache
		delete_transient( 'gb_framework_flickr_feed-' . $instance['widget_id'] );

		return $instance;
	}

	function widget( $args, $instance ) {

		extract( $args );

		$title = esc_attr( $instance['title'] );
		$flickr_id = esc_attr( $instance['flickr_id'] );
		$image_count = absint( $instance['image_count'] );
		$widget_id = esc_attr( $instance['widget_id'] );

		echo $before_widget;

		if( $title )
			echo $before_title . $title . $after_title;

		// Display images
		echo gb_framework_flickr_feed( $flickr_id, $image_count, $widget_id );

		echo $after_widget;
	}

}

add_action( 'widgets_init', create_function('', "register_widget('gb_Flickr_Feed_Widget');") );






/* ---------------------------------------------------- */
/*	Recent Posts
/* ---------------------------------------------------- */

class gb_Recent_Posts_Widget extends WP_Widget {

	function gb_Recent_Posts_Widget() {
		$widget_ops = array( 'classname' => 'gb-recent-posts', 'description' => __('Display recent posts.', 'gb_framework') );
		$this->WP_Widget( 'gb-recent-posts', __('Jedkey Recent Posts', 'gb_framework'), $widget_ops );
		$this->alt_option_name = 'gb_recent_posts_widget';
		
		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

  
  function widget($args, $instance) {
		$cache = wp_cache_get('gb_recent_posts_widget', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Jedkey Recent Posts', 'gb_framework') : $instance['title']);
		if ( !$number = (int) $instance['number'] )
			$number = 5;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 10 )
			$number = 10;

		$r = new WP_Query(array('showposts' => $number, 'nopaging' => 0, 'post_status' => 'publish'));
		if ($r->have_posts()) :
?>
		<?php echo $before_widget; ?>
		<?php if ( $title ) echo $before_title . $title . $after_title; ?>
		<?php  while ($r->have_posts()) : $r->the_post(); ?>
		<div class="latest-post">
			<?php if ( has_post_thumbnail() ) { ?>
				<?php global $post ?>
				<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>"><?php echo get_the_post_thumbnail($post->ID, 'blog-post-thumb-footer', array('title' => '')); ?></a> 
			<?php }else{ ?>
			  <?php global $post ?>
				<a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>"><img src="<?php echo ''.get_template_directory_uri().'/images/no_img_blog.jpg'; ?>" alt="" width="49" /></a> 
			<?php } ?>
			
			
				
				<p><a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a></p>
				<span><?php the_time(get_option('date_format')); ?></span>
			
			</div>
			<div class="clearfix"></div>
		<?php endwhile; ?>
		<?php echo $after_widget; ?>
<?php
			wp_reset_query();  // Restore global post data stomped by the_post().
		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_add('gb_recent_posts_widget', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['gb_recent_posts_widget']) )
			delete_option('gb_recent_posts_widget');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('gb_recent_posts_widget', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 5;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 10 )
			$number = 10;
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'gb_framework'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of posts to show:', 'gb_framework'); ?></label>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="2" /><br />
		<small><?php _e('(at most 10)', 'gb_framework'); ?></small></p>
<?php
	}


	

}

add_action( 'widgets_init', create_function('', "register_widget('gb_Recent_Posts_Widget');") );

?>